==> fbp-spec-0.6.0.tgz: package/lib/common.js <==
'use strict';

var Promise, rejectDelayer;

Promise = require('bluebird');

exports.isBrowser = function () {
  if (typeof process !== 'undefined' && process.execPath && process.execPath.match(/node|iojs/)) {
    return false;
  }
  return true;
};

exports.randomString = function (n) {
  var i, idx, j, possible, ref, text;
  text = "";
  possible = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
  for (i = j = 0, ref = n; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
    idx = Math.floor(Math.random() * possible.length);
    text += possible.charAt(idx);
  }
  return text;
};

exports.asyncSeries = function (items, func, callback) {
  var _next, results;
  items = items.slice(0);
  results = [];
  _next = function next() {
    var item;
    if (items.length === 0) {
      return callback(null, results);
    }
    item = items.shift();
    return func(item, function (err, result) {
      if (err) {
        return callback(err);
      }
      results.push(result);
      return _next();
    });
  };
  return _next();
};

exports.isArray = Array.isArray || function (value) {
  return {}.toString.call(value) === '[object Array]';
};

exports.startsWith = function (str, sub) {
  return str.indexOf(sub) === 0;
};

// Based on http://stackoverflow.com/a/38225011/1967571
rejectDelayer = function rejectDelayer(delay) {
  var f;
  f = function f(reason) {
    return new Promise(function (resolve, reject) {
      return setTimeout(reject.bind(null, reason), delay);
    });
  };
  return f;
};

exports.retryUntil = function (attempt, test) {
  var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 500;
  var max = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 5;

  var i, j, p, ref;
  p = Promise.reject(new Error('retry starter'));
  for (i = j = 0, ref = max; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
    p = p.catch(attempt).then(test).catch(rejectDelayer(delay));
  }
  return p;
};

==> fbp-spec-0.6.7.tgz: package/lib/common.js <==
"use strict";

var Promise, rejectDelayer;
Promise = require('bluebird');

exports.isBrowser = function () {
  if (typeof process !== 'undefined' && process.execPath && process.execPath.match(/node|iojs/)) {
    return false;
  }

  return true;
};

exports.randomString = function (n) {
  var i, idx, j, possible, ref, text;
  text = "";
  possible = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";

  for (i = j = 0, ref = n; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
    idx = Math.floor(Math.random() * possible.length);
    text += possible.charAt(idx);
  }

  return text;
};

exports.asyncSeries = function (items, func, callback) {
  var _next, results;

  items = items.slice(0);
  results = [];

  _next = function next() {
    var item;

    if (items.length === 0) {
      return callback(null, results);
    }

    item = items.shift();
    return func(item, function (err, result) {
      if (err) {
        return callback(err);
      }

      results.push(result);
      return _next();
    });
  };

  return _next();
};

exports.isArray = Array.isArray || function (value) {
  return {}.toString.call(value) === '[object Array]';
};

exports.startsWith = function (str, sub) {
  return str.indexOf(sub) === 0;
}; // Based on http://stackoverflow.com/a/38225011/1967571


rejectDelayer = function rejectDelayer(delay) {
  var f;

  f = function f(reason) {
    return new Promise(function (resolve, reject) {
      return setTimeout(reject.bind(null, reason), delay);
    });
  };

  return f;
};

exports.retryUntil = function (attempt, test) {
  var delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 500;
  var max = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 5;
  var i, j, p, ref;
  p = Promise.reject(new Error('retry starter'));

  for (i = j = 0, ref = max; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
    p = p["catch"](attempt).then(test)["catch"](rejectDelayer(delay));
  }

  return p;
};
